跳到主要内容

TaskLocalFuture

搜索

结构体 TaskLocalFuture 

pub struct TaskLocalFuture<T, F>
where T: 'static,
{ /* private fields */ }
展开描述

一个在执行期间为 future F 设置 task-local 值 T 的 future。

task-local 的值必须是 'static,并将在 future 完成时被丢弃。

由函数 LocalKey::scope 创建。

示例

tokio::task_local! {
    static NUMBER: u32;
}

NUMBER.scope(1, async move {
    println!("task local value: {}", NUMBER.get());
}).await;

实现

Source

impl<T, F> TaskLocalFuture<T, F>
where T: 'static,

pub fn take_value(self: Pin<&mut Self>) -> Option<T>

返回此 TaskLocalFuture 存储在 task-local 中的值。

此函数返回:

  • 如果 task-local 值存在,则为 Some(T)
  • 如果 task-local 值已经被取走,则为 None

请注意,即使 future 尚未完成,此函数也会尝试获取 task-local 的值。在这种情况下,调用 take_value 之后该值将无法再通过 task-local 访问。

示例
tokio::task_local! {
    static KEY: u32;
}

let fut = KEY.scope(42, async {
    // Do some async work
});

let mut pinned = Box::pin(fut);

// Complete the TaskLocalFuture
let _ = pinned.as_mut().await;

// And here, we can take task local value
let value = pinned.as_mut().take_value();

assert_eq!(value, Some(42));

Trait 实现

Source

impl<T, F> Debug for TaskLocalFuture<T, F>
where T: Debug + 'static,

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl<T: 'static, F> Drop for TaskLocalFuture<T, F>

Source

fn drop(&mut self)

执行此类型的析构函数。 更多信息
Source

impl<T: 'static, F: Future> Future for TaskLocalFuture<T, F>

Source

type Output = <F as Future>::Output

Future 完成时产生的值的类型。
Source

fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<Self::Output>

Attempts to resolve the future to a final value, registering the current task for wakeup if the value is not yet available. 更多信息
Source

impl<'__pin, T, F> Unpin for TaskLocalFuture<T, F>
where PinnedFieldsOf<__Origin<'__pin, T, F>>: Unpin, T: 'static,

自动 Trait 实现



impl<T, F> Freeze for TaskLocalFuture<T, F>
where T: Freeze, F: Freeze,



impl<T, F> RefUnwindSafe for TaskLocalFuture<T, F>



impl<T, F> Send for TaskLocalFuture<T, F>
where T: Send, F: Send,



impl<T, F> Sync for TaskLocalFuture<T, F>
where T: Sync, F: Sync,



impl<T, F> !UnsafeUnpin for TaskLocalFuture<T, F>



impl<T, F> UnwindSafe for TaskLocalFuture<T, F>
where T: UnwindSafe, F: UnwindSafe,

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows from an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows from an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

调用 U::from(self)

也就是说,此转换的具体行为取决于 From<T> for U 的实现方式。

Source

impl<F> IntoFuture for F
where F: Future,

Source

type Output = <F as Future>::Output

Future 完成时产生的输出。
Source

type IntoFuture = F

我们将要把此值转变成哪种 future?
Source

fn into_future(self) -> <F as IntoFuture>::IntoFuture

Creates a future from a value. 更多信息
Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。